@@ -7,7 +7,6 @@ import (
 
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
 	"github.com/confluentinc/cli/v3/pkg/config"
-	dynamicconfig "github.com/confluentinc/cli/v3/pkg/dynamic-config"
 	"github.com/confluentinc/cli/v3/pkg/output"
 )
 
@@ -68,7 +67,7 @@ func (c *command) describe(cmd *cobra.Command, args []string) error {
 	return describeContext(cmd, ctx)
 }
 
-func describeContext(cmd *cobra.Command, ctx *dynamicconfig.DynamicContext) error {
+func describeContext(cmd *cobra.Command, ctx *config.Context) error {
 	table := output.NewTable(cmd)
 	table.Add(&out{
 		Name:       ctx.Name,
