@@ -1,11 +1,8 @@
 package schemaregistry
 
 import (
-	"github.com/antihax/optional"
 	"github.com/spf13/cobra"
 
-	srsdk "github.com/confluentinc/schema-registry-sdk-go"
-
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
 	"github.com/confluentinc/cli/v3/pkg/config"
 	"github.com/confluentinc/cli/v3/pkg/output"
@@ -63,11 +60,7 @@ func (c *command) subjectList(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 
-	opts := &srsdk.ListOpts{
-		Deleted:       optional.NewBool(deleted),
-		SubjectPrefix: optional.NewString(prefix),
-	}
-	subjects, err := client.List(opts)
+	subjects, err := client.List(prefix, deleted)
 	if err != nil {
 		return err
 	}
